@@ -37,7 +37,7 @@ op = nk.optimizer.Sgd(ma, learning_rate=0.1)
 sr = nk.optimizer.SR(ma, diag_shift=0.1)
 
 # Stochastic reconfiguration
-gs = nk.Vmc(hamiltonian=ha, sampler=sa, optimizer=op, sr=sr, n_samples=1000)
+gs = nk.VMC(hamiltonian=ha, sampler=sa, optimizer=op, sr=sr, n_samples=1000)
 
 # Create a JSON output file, and overwrite if file exists
 logger = nk.logging.JsonLog("test", "w")
