@@ -19,11 +19,11 @@ from functools import partial
 
 import jax
 import jax.numpy as jnp
-import jax.experimental.host_callback as hcb
 import numpy as np
 from tqdm import tqdm
 
 import netket as nk
+from netket import config
 from netket.driver import AbstractVariationalDriver
 from netket.driver.abstract_variational_driver import _to_iterable
 from netket.driver.vmc_common import info
@@ -32,20 +32,32 @@ from netket.logging.json_log import JsonLog
 from netket.operator import AbstractOperator
 from netket.optimizer import LinearOperator
 from netket.optimizer.qgt import QGTAuto
-from netket.utils import mpi
+from netket.utils import mpi, pure_callback
 from netket.utils.dispatch import dispatch
 from netket.utils.types import PyTree
-from netket.vqs import VariationalState, VariationalMixedState, MCState
+from netket.vqs import VariationalState, VariationalMixedState, MCState, ExactState
 
 from netket.experimental.dynamics import RKIntegratorConfig
-from netket.experimental.dynamics._rk_solver import euclidean_norm, maximum_norm
+from netket.experimental.dynamics._rk_solver_structures import (
+    euclidean_norm,
+    maximum_norm,
+)
 
 
 class TDVP(AbstractVariationalDriver):
     """
     Variational time evolution based on the time-dependent variational principle which,
-    when used with Monte Carlo sampling via :ref:`netket.vqs.MCState`, is the time-dependent VMC
+    when used with Monte Carlo sampling via :class:`netket.vqs.MCState`, is the time-dependent VMC
     (t-VMC) method.
+
+    .. note::
+        This TDVP Driver uses the time-integrators from the `nkx.dynamics` module, which are
+        automatically executed under a `jax.jit` context.
+
+        When running computations on GPU, this can lead to infinite hangs or extremely long
+        compilation times. In those cases, you might try setting the configuration variable
+        :py:`nk.config.netket_experimental_disable_ode_jit = True` to mitigate those issues.
+
     """
 
     def __init__(
@@ -57,7 +69,7 @@ class TDVP(AbstractVariationalDriver):
         t0: float = 0.0,
         propagation_type="real",
         qgt: LinearOperator = None,
-        linear_solver=None,
+        linear_solver=nk.optimizer.solver.svd,
         linear_solver_restart: bool = False,
         error_norm: Union[str, Callable] = "euclidean",
     ):
@@ -74,6 +86,12 @@ class TDVP(AbstractVariationalDriver):
                 real-time Schrödinger equation (SE), "imag" for the imaginary-time SE.
             qgt: The QGT specification.
             linear_solver: The solver for solving the linear system determining the time evolution.
+                This must be a jax-jittable function :code:`f(A,b) -> x` that accepts a Matrix-like, Linear Operator
+                PyTree object :math:`A` and a vector-like PyTree :math:`b` and returns the PyTree :math:`x` solving
+                the system :math:`Ax=b`.
+                Defaults to :ref:`nk.optimizer.solver.svd` with the default svd threshold of 1e-10.
+                To change the svd threshold you can use :ref:`functools.partial` as follows:
+                :code:`functools.partial(nk.optimizer.solver.svd, rcond=1e-4)`.
             linear_solver_restart: If False (default), the last solution of the linear system
                 is used as initial value in subsequent steps.
             error_norm: Norm function used to calculate the error with adaptive integrators.
@@ -89,8 +107,6 @@ class TDVP(AbstractVariationalDriver):
         """
         self._t0 = t0
 
-        if linear_solver is None:
-            linear_solver = nk.optimizer.solver.svd
         if qgt is None:
             qgt = QGTAuto(solver=linear_solver)
 
@@ -191,15 +207,18 @@ class TDVP(AbstractVariationalDriver):
         elif error_norm == "maximum":
             self._error_norm = maximum_norm
         elif error_norm == "qgt":
-            w = self.state.parameters
-            norm_dtype = nk.jax.dtype_real(nk.jax.tree_dot(w, w))
-            # QGT norm is called via host callback since it accesses the driver
-            # TODO: make this also an hashablepartial on self to reduce recompilation
-            self._error_norm = lambda x: hcb.call(
-                HashablePartial(qgt_norm, self),
-                x,
-                result_shape=jax.ShapeDtypeStruct((), norm_dtype),
-            )
+            if config.netket_experimental_disable_ode_jit:
+                self._error_norm = HashablePartial(qgt_norm, self)
+            else:
+                w = self.state.parameters
+                norm_dtype = nk.jax.dtype_real(nk.jax.tree_dot(w, w))
+                # QGT norm is called via host callback since it accesses the driver
+                # TODO: make this also an hashablepartial on self to reduce recompilation
+                self._error_norm = lambda x: pure_callback(
+                    HashablePartial(qgt_norm, self),
+                    jax.ShapeDtypeStruct((), norm_dtype),
+                    x,
+                )
         else:
             raise ValueError(
                 "error_norm must be a callable or one of 'euclidean', 'qgt', 'maximum',"
@@ -307,7 +326,7 @@ class TDVP(AbstractVariationalDriver):
         """
         Runs the time evolution.
 
-        By default uses :ref:`netket.logging.JsonLog`. To know about the output format
+        By default uses :class:`netket.logging.JsonLog`. To know about the output format
         check it's documentation. The logger object is also returned at the end of this function
         so that you can inspect the results without reading the json output.
 
@@ -503,7 +522,9 @@ def odefun(state, driver, t, w, **kwargs):
 
 
 @dispatch
-def odefun(state: MCState, driver: TDVP, t, w, *, stage=0):  # noqa: F811
+def odefun(  # noqa: F811
+    state: Union[MCState, ExactState], driver: TDVP, t, w, *, stage=0
+):
     # pylint: disable=protected-access
 
     state.parameters = w
@@ -562,14 +583,17 @@ def odefun_host_callback(state, driver, *args, **kwargs):
     Calls odefun through a host callback in order to make the rest of the
     ODE solver jit-able.
     """
+    if config.netket_experimental_disable_ode_jit:
+        return odefun(state, driver, *args, **kwargs)
+
     result_shape = jax.tree_map(
         lambda x: jax.ShapeDtypeStruct(x.shape, x.dtype),
         state.parameters,
     )
 
-    return hcb.call(
+    return pure_callback(
         lambda args_and_kw: odefun(state, driver, *args_and_kw[0], **args_and_kw[1]),
-        # pack args and kwargs together, since host_callback passes a single argument:
+        result_shape,
+        # TODO: once we support only jax>0.3.17 pass directly args and kwargs
         (args, kwargs),
-        result_shape=result_shape,
     )
