@@ -25,7 +25,7 @@ __all__ = [
     "RK45",
 ]
 
-from ._rk_solver import RungeKuttaIntegrator, RKIntegratorConfig
+from ._rk_solver_structures import RungeKuttaIntegrator, RKIntegratorConfig
 from ._rk_solver import Euler, Heun, Midpoint, RK4, RK12, RK23, RK45
 
 from netket.utils import _hide_submodules
