@@ -14,6 +14,8 @@
 
 from typing import Optional, Union, List
 
+import numpy as np
+
 from netket.graph import AbstractGraph
 
 from .homogeneous import HomogeneousHilbert
@@ -42,6 +44,9 @@ class Qubit(HomogeneousHilbert):
 
         super().__init__([0.0, 1.0], N)
 
+    def states_to_local_indices(self, x):
+        return x.astype(np.int32)
+
     def __pow__(self, n):
         return Qubit(self.size * n)
 
