@@ -26,7 +26,7 @@ from netket.utils import HashableArray, warn_deprecation, deprecate_dtype
 from netket.utils.types import NNInitFunc
 from netket.utils.group import PermutationGroup
 from netket.graph import Graph, Lattice
-from netket.jax import logsumexp_cplx, is_complex, is_complex_dtype
+from netket.jax import logsumexp_cplx, is_complex_dtype
 from netket.nn.activation import reim_selu
 from netket.nn.symmetric_linear import (
     DenseSymmMatrix,
@@ -81,7 +81,7 @@ class GCNN_FFT(nn.Module):
     use_bias: bool = True
     """if True uses a bias in all layers."""
     precision: Any = None
-    """numerical precision of the computation see `jax.lax.Precision`for details."""
+    """numerical precision of the computation see :class:`jax.lax.Precision` for details."""
     kernel_init: NNInitFunc = default_gcnn_initializer
     """Initializer for the kernels of all layers."""
     bias_init: NNInitFunc = zeros
@@ -194,7 +194,7 @@ class GCNN_Irrep(nn.Module):
     use_bias: bool = True
     """if True uses a bias in all layers."""
     precision: Any = None
-    """numerical precision of the computation see `jax.lax.Precision`for details."""
+    """numerical precision of the computation see :class:`jax.lax.Precision` for details."""
     kernel_init: NNInitFunc = default_gcnn_initializer
     """Initializer for the kernels of all layers."""
     bias_init: NNInitFunc = zeros
@@ -296,7 +296,7 @@ class GCNN_Parity_FFT(nn.Module):
     parameters saved before PR#1030, but hinders performance.
     See also `nk.models.update_GCNN_parity`."""
     precision: Any = None
-    """numerical precision of the computation see `jax.lax.Precision`for details."""
+    """numerical precision of the computation see :class:`jax.lax.Precision` for details."""
     kernel_init: NNInitFunc = default_gcnn_initializer
     """Initializer for the kernels of all layers."""
     bias_init: NNInitFunc = zeros
@@ -472,7 +472,7 @@ class GCNN_Parity_Irrep(nn.Module):
     parameters saved before PR#1030, but hinders performance.
     See also `nk.models.update_GCNN_parity`."""
     precision: Any = None
-    """numerical precision of the computation see `jax.lax.Precision`for details."""
+    """numerical precision of the computation see :class:`jax.lax.Precision` for details."""
     kernel_init: NNInitFunc = default_gcnn_initializer
     """Initializer for the kernels of all layers."""
     bias_init: NNInitFunc = zeros
@@ -708,7 +708,7 @@ def GCNN(
         characters = HashableArray(np.ones(len(np.asarray(sg))))
     else:
         if (
-            not is_complex(characters)
+            not jnp.iscomplexobj(characters)
             and not is_complex_dtype(param_dtype)
             and not complex_output
             and jnp.any(characters < 0)
