@@ -15,7 +15,6 @@
 from math import sqrt
 from typing import Any, Callable, Iterable, Tuple, Union
 
-import jax
 from jax import numpy as jnp
 from jax.nn.initializers import zeros
 from plum import dispatch
@@ -28,6 +27,7 @@ from netket.models.autoreg import (
     _reshape_inputs,
 )
 from netket.nn import FastMaskedConv1D, FastMaskedConv2D, FastMaskedDense1D
+from netket.nn import activation as nkactivation
 from netket.nn.masked_linear import default_kernel_init
 from netket.utils.types import Array, DType, NNInitFunc
 from netket.utils import deprecate_dtype
@@ -47,16 +47,16 @@ class FastARNNDense(AbstractARNN):
     layers: int
     """number of layers."""
     features: Union[Iterable[int], int]
-    """number of features in each layer. If a single number is given,
+    """output feature density in each layer. If a single number is given,
     all layers except the last one will have the same number of features."""
-    activation: Callable[[Array], Array] = jax.nn.selu
-    """the nonlinear activation function between hidden layers (default: selu)."""
+    activation: Callable[[Array], Array] = nkactivation.reim_selu
+    """the nonlinear activation function between hidden layers (default: reim_selu)."""
     use_bias: bool = True
     """whether to add a bias to the output (default: True)."""
     param_dtype: DType = jnp.float64
     """the dtype of the computation (default: float64)."""
     precision: Any = None
-    """numerical precision of the computation, see `jax.lax.Precision` for details."""
+    """numerical precision of the computation, see :class:`jax.lax.Precision` for details."""
     kernel_init: NNInitFunc = default_kernel_init
     """initializer for the weights."""
     bias_init: NNInitFunc = zeros
@@ -107,20 +107,20 @@ class FastARNNConv1D(AbstractARNN):
     layers: int
     """number of layers."""
     features: Union[Iterable[int], int]
-    """number of features in each layer. If a single number is given,
+    """output feature density in each layer. If a single number is given,
     all layers except the last one will have the same number of features."""
     kernel_size: int
     """length of the convolutional kernel."""
     kernel_dilation: int = 1
     """dilation factor of the convolution kernel (default: 1)."""
-    activation: Callable[[Array], Array] = jax.nn.selu
-    """the nonlinear activation function between hidden layers (default: selu)."""
+    activation: Callable[[Array], Array] = nkactivation.reim_selu
+    """the nonlinear activation function between hidden layers (default: reim_selu)."""
     use_bias: bool = True
     """whether to add a bias to the output (default: True)."""
     param_dtype: DType = jnp.float64
     """the dtype of the computation (default: float64)."""
     precision: Any = None
-    """numerical precision of the computation, see `jax.lax.Precision` for details."""
+    """numerical precision of the computation, see :class:`jax.lax.Precision` for details."""
     kernel_init: NNInitFunc = default_kernel_init
     """initializer for the weights."""
     bias_init: NNInitFunc = zeros
@@ -171,21 +171,21 @@ class FastARNNConv2D(AbstractARNN):
     layers: int
     """number of layers."""
     features: Union[Iterable[int], int]
-    """number of features in each layer. If a single number is given,
+    """output feature density in each layer. If a single number is given,
     all layers except the last one will have the same number of features."""
     kernel_size: Tuple[int, int]
     """shape of the convolutional kernel `(h, w)`. Typically, `h = w // 2 + 1`."""
     kernel_dilation: Tuple[int, int] = (1, 1)
     """a sequence of 2 integers, giving the dilation factor to
     apply in each spatial dimension of the convolution kernel (default: 1)."""
-    activation: Callable[[Array], Array] = jax.nn.selu
-    """the nonlinear activation function between hidden layers (default: selu)."""
+    activation: Callable[[Array], Array] = nkactivation.reim_selu
+    """the nonlinear activation function between hidden layers (default: reim_selu)."""
     use_bias: bool = True
     """whether to add a bias to the output (default: True)."""
     param_dtype: DType = jnp.float64
     """the dtype of the computation (default: float64)."""
     precision: Any = None
-    """numerical precision of the computation, see `jax.lax.Precision` for details."""
+    """numerical precision of the computation, see :class:`jax.lax.Precision` for details."""
     kernel_init: NNInitFunc = default_kernel_init
     """initializer for the weights."""
     bias_init: NNInitFunc = zeros
