@@ -18,12 +18,12 @@ from functools import partial
 import jax
 from flax import linen as nn
 from jax import numpy as jnp
-from jax.experimental import host_callback as hcb
 
 from netket.nn import to_array
 from netket.utils import struct
 from netket.utils.deprecation import warn_deprecation
 from netket.utils.types import PyTree, SeedT
+from netket.utils import pure_callback
 
 from .base import Sampler, SamplerState
 
@@ -113,13 +113,13 @@ class ExactSampler(Sampler):
         # For future investigators:
         # this will lead to a crash if numbers_to_state throws.
         # it throws if we feed it nans!
-        samples = hcb.call(
+        samples = pure_callback(
             lambda numbers: sampler.hilbert.numbers_to_states(numbers),
-            numbers,
-            result_shape=jax.ShapeDtypeStruct(
+            jax.ShapeDtypeStruct(
                 (chain_length * sampler.n_chains_per_rank, sampler.hilbert.size),
                 jnp.float64,
             ),
+            numbers,
         )
         samples = jnp.asarray(samples, dtype=sampler.dtype).reshape(
             chain_length, sampler.n_chains_per_rank, sampler.hilbert.size
