@@ -19,6 +19,7 @@ from . import struct
 from . import numbers
 from . import types
 from . import float
+from . import errors
 
 from .array import HashableArray
 from .partial import HashablePartial
@@ -32,6 +33,7 @@ from .deprecation import (
     deprecated,
     deprecated_new_name,
     deprecate_dtype,
+    pure_callback,
 )
 from .moduletools import _hide_submodules, rename_class, auto_export as _auto_export
 from .version_check import module_version
@@ -46,5 +48,7 @@ from . import mpi
 from . import _dependencies_check
 
 _hide_submodules(
-    __name__, remove_self=False, ignore=["numbers", "types", "float", "dispatch"]
+    __name__,
+    remove_self=False,
+    ignore=["numbers", "types", "float", "dispatch", "errors"],
 )
