@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import Union
+
 import os
 from textwrap import dedent
 
@@ -40,7 +42,7 @@ def int_env(varname: str, default: int) -> int:
     return int(os.getenv(varname, default))
 
 
-def get_env(varname: str, type, default: int):
+def get_env(varname: str, type, default: Union[int, bool]) -> Union[int, bool]:
     if type is int:
         return int_env(varname, default)
     elif type is bool:
@@ -202,6 +204,20 @@ config.define(
     runtime=True,
 )
 
+config.define(
+    "NETKET_EXPERIMENTAL_DISABLE_ODE_JIT",
+    bool,
+    default=False,
+    help=dedent(
+        """
+        Disables the jitting of the whole ode solver, mainly used within TDVP solvers.
+        The jitting is sometimes incompatible with GPU-based calculations, and on large
+        calculations it gives negligible speedups so it might be beneficial to disable it.
+        """
+    ),
+    runtime=True,
+)
+
 config.define(
     "NETKET_SPHINX_BUILD",
     bool,
