@@ -98,7 +98,7 @@ def test_mutation(PointT):
 @pytest.mark.parametrize("PointT", [Point0, Point1])
 def test_pytree_nodes(PointT):
     p = PointT(x=1, y=2, meta={"abc": True})
-    leaves = jax.tree_leaves(p)
+    leaves = jax.tree_util.tree_leaves(p)
     assert leaves == [1, 2]
     new_p = jax.tree_map(lambda x: x + x, p)
     assert new_p == PointT(x=2, y=4, meta={"abc": True})
@@ -107,7 +107,7 @@ def test_pytree_nodes(PointT):
 def test_pytree_nodes_inheritance():
     p = Point1Child(x=1, y=2, z=3, meta={"abc": True})
     _ = Point1Child(1, 2, {"abc": True}, 3)
-    leaves = jax.tree_leaves(p)
+    leaves = jax.tree_util.tree_leaves(p)
     assert leaves == [1, 2, 3]
     new_p = jax.tree_map(lambda x: x + x, p)
     assert new_p == Point1Child(x=2, y=4, z=6, meta={"abc": True})
